package com.inspect.metadata.montdata.mapper;

import com.inspect.metadata.montdata.domain.BasedataMontTaskStaData;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface BasedataMontTaskStaDataMapper {
    BasedataMontTaskStaData selectBasedataMontTaskStaDataByTaskStaDataId(Long staDataId);

    List<BasedataMontTaskStaData> selectBasedataMontTaskStaDataList(BasedataMontTaskStaData data);

    int insertBasedataMontTaskStaData(BasedataMontTaskStaData data);

    int updateBasedataMontTaskStaData(BasedataMontTaskStaData data);

    int deleteBasedataMontTaskStaDataByTaskStaDataId(Long staDataId);

    int deleteBasedataMontTaskStaDataByTaskStaDataIds(Long[] staDataIds);
}
